@@ -1,4 +1,3 @@
-from mvcbotbase import social_network_provider_implementations, command_info
 from mvcbotbase.classes_for_command_arguments import (
     BaseArg, IntArg, WordArg, StringArg, Sequence
 )
@@ -10,14 +9,16 @@ from mvcbotbase.message_classes import (
 )
 from mvcbotbase.mvcbotbase import MVCBotBase
 from mvcbotbase.social_network_provider import SocialNetworkProvider
+from mvcbotbase import social_network_provider_implementations, command_info
 
 __all__ = [
-    "MVCBotBase", "social_network_provider_implementations",
+    "MVCBotBase",
     "SocialNetworkProvider", "social_network_provider", "BaseArg", "IntArg",
     "mvcbotbase", "WordArg", "StringArg", "Sequence", "AttachmentType",
     "OutgoingMessage", "OutgoingAttachment", "OutgoingFileAttachment",
     "Attachment", "UndownloadableAttachment", "AbstractIncomingAttachment",
     "AbstractIncomingMessage", "message_classes",
     "AttachmentToUploadHasUnknownFileTypeError", "ContentCantBeDownloadedError",
-    "classes_for_command_arguments", "command_info"
+    "classes_for_command_arguments", "command_info",
+    "social_network_provider_implementations"
 ]
